package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcRecruit;

/**
 * cmc员工招聘Service接口
 * 
 * @author cmc
 * @date 2025-10-16
 */
public interface ICmcRecruitService 
{
    /**
     * 查询cmc员工招聘
     * 
     * @param recruitId cmc员工招聘主键
     * @return cmc员工招聘
     */
    public CmcRecruit selectCmcRecruitByRecruitId(String recruitId);

    /**
     * 查询cmc员工招聘列表
     * 
     * @param cmcRecruit cmc员工招聘
     * @return cmc员工招聘集合
     */
    public List<CmcRecruit> selectCmcRecruitList(CmcRecruit cmcRecruit);

    /**
     * 新增cmc员工招聘
     * 
     * @param cmcRecruit cmc员工招聘
     * @return 结果
     */
    public int insertCmcRecruit(CmcRecruit cmcRecruit);

    /**
     * 修改cmc员工招聘
     * 
     * @param cmcRecruit cmc员工招聘
     * @return 结果
     */
    public int updateCmcRecruit(CmcRecruit cmcRecruit);

    /**
     * 批量删除cmc员工招聘
     * 
     * @param recruitIds 需要删除的cmc员工招聘主键集合
     * @return 结果
     */
    public int deleteCmcRecruitByRecruitIds(String[] recruitIds);

    /**
     * 删除cmc员工招聘信息
     * 
     * @param recruitId cmc员工招聘主键
     * @return 结果
     */
    public int deleteCmcRecruitByRecruitId(String recruitId);
}
